@@ -17,10 +17,12 @@ __init__.py
 """
 
 from apafib.datasets import fetch_apa_data, load_BCN_IBEX, load_BCN_UK, load_BCN_vuelos, \
-     load_medical_costs, load_stroke, load_wind_prediction 
+     load_medical_costs, load_stroke, load_wind_prediction, load_titanic, load_crabs, \
+          load_life_expectancy, load_electric_devices 
 
 from apafib.classifiers import BlackBoxClassifier, BlackBoxRegressor
 
+__version__ = '0.0.9'
 
 __all__ = ['fetch_apa_data', 
            'BlackBoxClassifier', 
@@ -30,5 +32,9 @@ __all__ = ['fetch_apa_data',
            'load_BCN_vuelos',
            'load_medical_costs',
            'load_wind_prediction',
-           'load_stroke'
+           'load_stroke',
+           'load_titanic',
+           'load_crabs',
+           'load_life_expectancy', 
+           'load_electric_devices'
            ]
\ No newline at end of file
