@@ -85,6 +85,19 @@ def load_BCN_UK():
 def load_BCN_vuelos():
     return fetch_dataset('BCNDiari2021-vuelos')
 
+def load_titanic():
+    return fetch_dataset('titanic')
+
+def load_crabs():
+    return fetch_dataset('crabs').drop(columns='index')
+
+def load_life_expectancy():
+    return fetch_dataset('Life_Expectancy_Data')
+
+def load_electric_devices():
+    data =  pd.read_csv(f'{DATALINK}/ElectricDevices_TRAIN.csv', header=None, na_values='?')
+    data.columns = ['Class'] + [f'H{i:02d}:{j}' for i in range(24) for j in ['00', '15', '30', '45']]
+    return data
 
 
 
